EphemeralSecret

Struct EphemeralSecret 

pub struct EphemeralSecret(pub(crate) [u8; 32]);
A short-lived Diffie-Hellman secret key that can only be used to compute a single SharedSecret.

This type is identical to the StaticSecret type, except that the EphemeralSecret::diffie_hellman method consumes and then wipes the secret key, and there are no serialization methods defined. This means that EphemeralSecrets can only be generated from fresh randomness where the compiler statically checks that the resulting secret is used at most once.

Tuple Fields

0: [u8; 32]

Implementations

Source

impl EphemeralSecret

pub fn diffie_hellman(self, their_public: &PublicKey) -> SharedSecret

Perform a Diffie-Hellman key agreement between self and their_public key to produce a SharedSecret.

pub fn random_from_rng<R: CryptoRng + ?Sized>(csprng: &mut R) -> Self

Generate a new EphemeralSecret with the supplied RNG.

pub fn random() -> Self

Generate a new EphemeralSecret.